A fast way to produce a reference list in an r-markdown document from a
lib_df object.
This function may or may not produce intermediate files (bib and Rmd) and the
result can be assigned to an object for further edition
(see yamlme::update()).
A html file will be written by write_rmd() and render_rmd() in the
working directory and displayed by browseURL().
reflist(x, ...)# S3 method for character
reflist(
x,
output_file,
delete_source = TRUE,
title = "Automatic Reference List",
output = "html_document",
nocite = "'@*'",
urlcolor = "blue",
encoding = "UTF-8",
...
)
# S3 method for lib_df
reflist(x, filename, delete_source = TRUE, ...)
An invisible object of class rmd_doc. A Rmd file will be written by
write_rmd() as well.
A lib_df object to produce the reference list. In the character
method, a character value indicating the path of a bibtex file
(passed to read_bib()).
Further arguments passed to the yaml header in the intermediate Rmarkdown document.
A character value with the name for the written Rmarkdown file.
A logical value indicating whether written bib file should be deleted after rendering html or not.
Arguments used for the yaml-header in
r-markdown and passed to write_rmd(). They can be cancelled using the
value NULL (not recommended for nocite).
A character value indicating the encoding string. It is
passed to write_bib().
A character value with the name for the written Rmd file, without file extension.
if (FALSE) {
reflist(synopsis)
}
Run the code above in your browser using DataLab